@@ -2,13 +2,16 @@ package File::Format::RIFF::List;
 use base File::Format::RIFF::Container;
 
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
+
+
+use Carp;
 
 
 sub new
 {
    my ( $proto, %args ) = @_;
-   die "Cannot set id of LIST chunk" if ( exists $args{id} );
+   croak "Cannot set id of LIST chunk" if ( exists $args{id} );
    return $proto->SUPER::new( %args, id => 'LIST' );
 }
 
